<?php

namespace Assetdocs\Branchmaster\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Branchmaster\Http\Requests\BranchmasterAdminApiRequest;
use Assetdocs\Branchmaster\Interfaces\BranchmasterRepositoryInterface;
use Assetdocs\Branchmaster\Models\Branchmaster;

/**
 * Admin API controller class.
 */
class BranchmasterAdminApiController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'admin.api';

    /**
     * Initialize branchmaster controller.
     *
     * @param type BranchmasterRepositoryInterface $branchmaster
     *
     * @return type
     */
    public function __construct(BranchmasterRepositoryInterface $branchmaster)
    {
        $this->middleware('api');
        $this->middleware('jwt.auth:admin.api');
        $this->setupTheme(config('theme.themes.admin.theme'), config('theme.themes.admin.layout'));

        $this->repository = $branchmaster;
        parent::__construct();
    }

    /**
     * Display a list of branchmaster.
     *
     * @return json
     */
    public function index(BranchmasterAdminApiRequest $request)
    {
        $branchmasters  = $this->repository
            ->pushCriteria(new \Assetdocs\Branchmaster\Repositories\Criteria\BranchmasterAdminCriteria())
            ->setPresenter('\\Assetdocs\\Branchmaster\\Repositories\\Presenter\\BranchmasterListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $branchmasters['code'] = 2000;
        return response()->json($branchmasters) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display branchmaster.
     *
     * @param Request $request
     * @param Model   Branchmaster
     *
     * @return Json
     */
    public function show(BranchmasterAdminApiRequest $request, Branchmaster $branchmaster)
    {
        $branchmaster         = $branchmaster->presenter();
        $branchmaster['code'] = 2001;
        return response()->json($branchmaster)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new branchmaster.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(BranchmasterAdminApiRequest $request, Branchmaster $branchmaster)
    {
        $branchmaster         = $branchmaster->presenter();
        $branchmaster['code'] = 2002;
        return response()->json($branchmaster)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new branchmaster.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(BranchmasterAdminApiRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $branchmaster          = $this->repository->create($attributes);
            $branchmaster          = $branchmaster->presenter();
            $branchmaster['code']  = 2004;

            return response()->json($branchmaster)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
;
        }
    }

    /**
     * Show branchmaster for editing.
     *
     * @param Request $request
     * @param Model   $branchmaster
     *
     * @return json
     */
    public function edit(BranchmasterAdminApiRequest $request, Branchmaster $branchmaster)
    {
        $branchmaster         = $branchmaster->presenter();
        $branchmaster['code'] = 2003;
        return response()-> json($branchmaster)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the branchmaster.
     *
     * @param Request $request
     * @param Model   $branchmaster
     *
     * @return json
     */
    public function update(BranchmasterAdminApiRequest $request, Branchmaster $branchmaster)
    {
        try {

            $attributes = $request->all();

            $branchmaster->update($attributes);
            $branchmaster         = $branchmaster->presenter();
            $branchmaster['code'] = 2005;

            return response()->json($branchmaster)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the branchmaster.
     *
     * @param Request $request
     * @param Model   $branchmaster
     *
     * @return json
     */
    public function destroy(BranchmasterAdminApiRequest $request, Branchmaster $branchmaster)
    {

        try {

            $t = $branchmaster->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('branchmaster::branchmaster.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
