<?php

namespace Assetdocs\Branchmaster\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Form;
use Assetdocs\Branchmaster\Http\Requests\BranchmasterAdminWebRequest;
use Assetdocs\Branchmaster\Interfaces\BranchmasterRepositoryInterface;
use Assetdocs\Branchmaster\Models\Branchmaster;

/**
 * Admin web controller class.
 */
class BranchmasterAdminController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'admin.web';

    /**
     * Initialize branchmaster controller.
     *
     * @param type BranchmasterRepositoryInterface $branchmaster
     *
     * @return type
     */
    public function __construct(BranchmasterRepositoryInterface $branchmaster)
    {
        $this->middleware('web');
        $this->middleware('auth:admin.web');
        $this->setupTheme(config('theme.themes.admin.theme'), config('theme.themes.admin.layout'));

        $this->repository = $branchmaster;
        parent::__construct();
    }

    /**
     * Display a list of branchmaster.
     *
     * @return Response
     */
    public function index(BranchmasterAdminWebRequest $request)
    {
        $pageLimit = $request->input('pageLimit');
        if ($request->wantsJson()) {
            $branchmasters  = $this->repository
            ->pushCriteria(new \Assetdocs\Branchmaster\Repositories\Criteria\BranchmasterAdminCriteria())
                ->setPresenter('\\Assetdocs\\Branchmaster\\Repositories\\Presenter\\BranchmasterListPresenter')
                ->scopeQuery(function ($query) {
                    return $query->orderBy('id', 'DESC');
                })->paginate($pageLimit);

            $branchmasters['recordsTotal']    = $branchmasters['meta']['pagination']['total'];
            $branchmasters['recordsFiltered'] = $branchmasters['meta']['pagination']['total'];
            $branchmasters['request']         = $request->all();
            return response()->json($branchmasters, 200);

        }

        $this   ->theme->prependTitle(trans('branchmaster::branchmaster.names').' :: ');
        return $this->theme->of('branchmaster::admin.branchmaster.index')->render();
    }

    /**
     * Display branchmaster.
     *
     * @param Request $request
     * @param Model   $branchmaster
     *
     * @return Response
     */
    public function show(BranchmasterAdminWebRequest $request, Branchmaster $branchmaster)
    {
        if (!$branchmaster->exists) {
            return response()->view('branchmaster::admin.branchmaster.new', compact('branchmaster'));
        }

        Form::populate($branchmaster);
        return response()->view('branchmaster::admin.branchmaster.show', compact('branchmaster'));
    }

    /**
     * Show the form for creating a new branchmaster.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BranchmasterAdminWebRequest $request)
    {

        $branchmaster = $this->repository->newInstance([]);

        Form::populate($branchmaster);

        return response()->view('branchmaster::admin.branchmaster.create', compact('branchmaster'));

    }

    /**
     * Create new branchmaster.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BranchmasterAdminWebRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $branchmaster          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('branchmaster::branchmaster.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/branchmaster/branchmaster/'.$branchmaster->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show branchmaster for editing.
     *
     * @param Request $request
     * @param Model   $branchmaster
     *
     * @return Response
     */
    public function edit(BranchmasterAdminWebRequest $request, Branchmaster $branchmaster)
    {
        Form::populate($branchmaster);
        return  response()->view('branchmaster::admin.branchmaster.edit', compact('branchmaster'));
    }

    /**
     * Update the branchmaster.
     *
     * @param Request $request
     * @param Model   $branchmaster
     *
     * @return Response
     */
    public function update(BranchmasterAdminWebRequest $request, Branchmaster $branchmaster)
    {
        try {

            $attributes = $request->all();

            $branchmaster->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('branchmaster::branchmaster.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/branchmaster/branchmaster/'.$branchmaster->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/branchmaster/branchmaster/'.$branchmaster->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the branchmaster.
     *
     * @param Model   $branchmaster
     *
     * @return Response
     */
    public function destroy(BranchmasterAdminWebRequest $request, Branchmaster $branchmaster)
    {

        try {

            $t = $branchmaster->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('branchmaster::branchmaster.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/branchmaster/branchmaster/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/branchmaster/branchmaster/'.$branchmaster->getRouteKey()),
            ], 400);
        }
    }
}
